@@ -39,7 +39,7 @@ use warnings::unused;
 
 our @EXPORT = qw( retrieve report newretrieve newreport get_files );
 
-$VERSION = '0.55'; # our $VERSION = '';
+$VERSION = '0.55.3'; # our $VERSION = '';
 $ABSTRACT = 'Sim::OPT::Report is the module used by Sim::OPT to retrieve simulation results.';
 
 #########################################################################################
@@ -160,35 +160,35 @@ sub retrieve
   foreach my $instance (@instances)
   {
     my %d = %{$instance};
-    my $countcase = $d{countcase}; say $tee "dump(\$countcase): " . dump($countcase);
-    my $countblock = $d{countblock}; say $tee "dump(\$countblock): " . dump($countblock);
-    my %datastruc = %{ $d{datastruc} }; say $tee "dump(\%datastruc): " . dump(%datastruc);######
-    my @rescontainer = @{ $d{rescontainer} }; say $tee "dump(\%rescontainer): " . dump(%rescontainer);######
-    my @miditers = @{ $d{miditers} }; say $tee "dump(\@miditers): " . dump(@miditers);
-    my @winneritems = @{ $d{winneritems} }; say $tee  "dumpIN( \@winneritems) " . dump(@winneritems);
-    my $countvar = $d{countvar}; say $tee "dump(\$countvar): " . dump($countvar );
-    my $countstep = $d{countstep}; say $tee "dump(\$countstep): " . dump($countstep);
-    my $to = $d{to}; say $tee "dump(\$to): " . dump($to);
-    my $origin = $d{origin}; say $tee "dump(\$origin): " . dump($origin);
-    my @uplift = @{ $d{uplift} }; say $tee "dump(\@uplift): " . dump(@uplift);
-    my @backvalues = @{ $d{backvalues} }; say $tee "IN RETRIEVE \@backvalues " . dump(@backvalues);
-    my @sweeps = @{ $d{sweeps} }; say $tee "dump(\@sweeps): " . dump(@sweeps);
-    my @sourcesweeps = @{ $d{sourcesweeps} }; say $tee "dump(\@sourcesweeps): " . dump(@sourcesweeps);
+    my $countcase = $d{countcase}; #say $tee "dump(\$countcase): " . dump($countcase);
+    my $countblock = $d{countblock}; #say $tee "dump(\$countblock): " . dump($countblock);
+    my %datastruc = %{ $d{datastruc} }; #say $tee "dump(\%datastruc): " . dump(%datastruc);######
+    my @rescontainer = @{ $d{rescontainer} }; #say $tee "dump(\%rescontainer): " . dump(%rescontainer);######
+    my @miditers = @{ $d{miditers} }; #say $tee "dump(\@miditers): " . dump(@miditers);
+    my @winneritems = @{ $d{winneritems} }; #say $tee  "dumpIN( \@winneritems) " . dump(@winneritems);
+    my $countvar = $d{countvar}; #say $tee "dump(\$countvar): " . dump($countvar );
+    my $countstep = $d{countstep}; #say $tee "dump(\$countstep): " . dump($countstep);
+    my $to = $d{to}; #say $tee "dump(\$to): " . dump($to);
+    my $origin = $d{origin}; #say $tee "dump(\$origin): " . dump($origin);
+    my @uplift = @{ $d{uplift} }; #say $tee "dump(\@uplift): " . dump(@uplift);
+    my @backvalues = @{ $d{backvalues} }; #say $tee "IN RETRIEVE \@backvalues " . dump(@backvalues);
+    my @sweeps = @{ $d{sweeps} }; #say $tee "dump(\@sweeps): " . dump(@sweeps);
+    my @sourcesweeps = @{ $d{sourcesweeps} }; #say $tee "dump(\@sourcesweeps): " . dump(@sourcesweeps);
     
     #eval($getparshere);
     
     my $skip = $vals{$countvar}{skip}; 
     
-    my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); say $tee "dump(\$rootname): " . dump($rootname);
-    my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); say $tee "dump(\$numberof_simtools ): " . dump($numberof_simtools );
+    my $rootname = Sim::OPT::getrootname(\@rootnames, $countcase); #say $tee "dump(\$rootname): " . dump($rootname);
+    my $numberof_simtools = scalar ( keys %{ $dowhat{simtools} } ); #say $tee "dump(\$numberof_simtools ): " . dump($numberof_simtools );
     
     my $counttool = 1;
     while ( $counttool <= $numberof_simtools ) 
     {  
-      my $skip = $vals{$countvar}{$counttool}{skip}; say $tee "dump(\$skip): " . dump($skip);
+      my $skip = $vals{$countvar}{$counttool}{skip}; #say $tee "dump(\$skip): " . dump($skip);
       if ( not ( eval ( $skipsim{$counttool} )))
       {
-        my $tooltype = $dowhat{simtools}{$counttool}; say $tee "dump(\$tooltype ): " . dump($tooltype );
+        my $tooltype = $dowhat{simtools}{$counttool}; #say $tee "dump(\$tooltype ): " . dump($tooltype );
 
         sub retrieve_temperatures_results 
         {
@@ -833,7 +833,7 @@ $printthis
   close RETBLOCK;
   
   
-  say $tee "\@notecases " . dump( @notecases ); 
+  #say $tee "\@notecases " . dump( @notecases ); 
 
   return ( \@retcases, \@retstruct, \@notecases );
 }  # END SUB RETRIEVE
@@ -1636,8 +1636,8 @@ $printthis
     }
   }
   
-  print `rm -f $mypath/*.par`;
-  print TOFILE "rm -f $mypath/*.par\n";
+  `rm -f $mypath/*.par`;
+  print $tee "rm -f $mypath/*.par\n";
   close OUTFILE;
   close TOFILE;
   close RETLIST;
@@ -1646,7 +1646,7 @@ $printthis
   
   say $tee "\@notecases " . dump( @notecases ); 
 
-  if ( $dowhat{erasenewres} eq "y" )
+  if ( $dowhat{neweraseres} eq "y" )
   {
     `rm -f $resfile` ;
   }
@@ -2462,6 +2462,13 @@ sub newreport # This function retrieves the results of interest from the texts f
   
   close TOFILE;
   close OUTFILE;
+
+  if ( $dowhat{neweraseret} eq "y" )
+  {
+    `rm -f $mypath/*.grt` ;
+    print $tee "rm -f $mypath/*.grt";
+  }
+  
   return ( \@repcases, \@repstruct, \@mergestruct, \@mergecases, $repfile ); 
 } # END SUB NEWREPORT;
 
