@@ -571,11 +571,11 @@ $printthis
 
     
 
-    say $tee "DUE resfile: $resfile!";
+    #say $tee "DUE resfile: $resfile!";
 
     if ( $dowhat{newretrieve} eq "y" )
     {
-      say $tee "INSIM1: countinstance: $countinstance";
+      #say $tee "INSIM1: countinstance: $countinstance";
       my @result = Sim::OPT::Report::newretrieve( 
       { 
         instances => \@instances, countcase => $countcase, countblock => $countblock, 
@@ -589,7 +589,7 @@ $printthis
 
     if ( $dowhat{newreport} eq "y" )
     { 
-      say $tee "INSIM2: countinstance: $countinstance";
+      #say $tee "INSIM2: countinstance: $countinstance";
       my @result = Sim::OPT::Report::newreport( 
       { 
         instances => \@instances, countcase => $countcase, countblock => $countblock, 
